USE [ProSolutionReports]
GO

/*
--Sample Import Views for OneGrade VA 21/22
--For use with ProSolution
--For OneGrade Version 1.23 onwards
*/


SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO


CREATE VIEW [vOG_2122_Enrolment]
AS

----------------------------------------------------
--Enrolment Import Template for OneGrade VA
----------------------------------------------------

SELECT
T.AcademicYearID,
T.LearnerRef,
T.LearningAimRef,
T.CourseCode,
T.CompletionStatusID,
Enr.Grade,
T.StartDate,
Enr.ExpectedEndDate,
Enr.ActualEndDate,
LTRIM(RTRIM(CollegeLevels.Level2Code)) + ' - ' + LEFT(CollegeLevels.Level2Name,200) AS UDFS1, --College Level Code and Name - alter to Level 1, 2, 3, 4 as desired
NULL AS UDFS2,
NULL AS UDFS3, NULL AS UDFS4, 
NULL AS UDFNum, NULL AS UDFDate,
NULL AS UDFS5, NULL AS UDFS6, 
NULL AS UDFS7, NULL AS UDFS8, 
NULL AS UDFNum2,
[Off].Code AS TeachingGroupCode,
[Off].[Name] AS TeachingGroupName,
Enr.OutcomeID

FROM
	(
			--This will return the key enrolment records and avoid duplicates
			SELECT DISTINCT
				Min(E.EnrolmentID) AS MinEnrolmentID,	
				SD.AcademicYearID,			--*UniqueKey
				SD.RefNo AS LearnerRef,		--*UniqueKey
				O.QualID AS LearningAimRef,	--*UniqueKey
				C.CourseCode,				--*UniqueKey
				E.CompletionStatusID,		--*UniqueKey
				E.StartDate					--*UniqueKey

			FROM         
				ProSolution.dbo.Enrolment AS E WITH (NOLOCK) 
				INNER JOIN ProSolution.dbo.Offering AS O WITH (NOLOCK)
					 ON E.OfferingID = O.OfferingID
						INNER JOIN ProSolution.dbo.Learning_Aim AS LA WITH (NOLOCK)
						ON O.QualID = LA.LEARNING_AIM_REF
							INNER JOIN ProSolution.dbo.StudentDetail AS SD WITH (NOLOCK)
							ON E.StudentDetailID = SD.StudentDetailID
								INNER JOIN vOG_CourseCode AS C WITH (NOLOCK)
								ON O.OfferingID = C.OfferingID

			WHERE     
				SD.AcademicYearID = '21/22'
				AND E.CompletionStatusID NOT IN ('X') --cancelled
				--AND LA.NOTIONAL_NVQ_LEVEL_CODE IN ('2','3') --L2, L3
				AND O.OfferingTypeID IN (8, 17) --FE Programme, Apprenticeship component
				--AND O.QualID NOT LIKE 'Z%' --Don't include Z code Learning Aims
			
			GROUP BY 
				SD.AcademicYearID, SD.RefNo, O.QualID, C.CourseCode, E.CompletionStatusID, E.StartDate
	) T

--ensure that we join on T.MinEnrolmentID
INNER JOIN ProSolution.dbo.Enrolment AS Enr WITH (NOLOCK)
ON T.MinEnrolmentID = Enr.EnrolmentID
	INNER JOIN ProSolution.dbo.Offering AS [Off] WITH (NOLOCK)
	ON Enr.OfferingID = [Off].OfferingID

	LEFT JOIN --College Structure
	(
		--Level1
		SELECT
			CL1.[SID], CL1.Code AS Level1Code, '' AS Level2Code, '' AS Level3Code, '' AS Level4Code, CL1.[Name] AS Level1Name, '' AS Level2Name, '' AS Level3Name, '' AS Level4Name
		FROM 
			ProSolution.dbo.CollegeLevel CL1 WITH (NOLOCK)
			RIGHT JOIN ProSolution.dbo.AcademicYear AcYr WITH (NOLOCK) 
			ON ISNULL(CL1.MaxAcademicYearID, '21/22') = AcYr.AcademicYearID
		WHERE
			CL1.[Enabled] = 1 AND LevelNum = 1
		
		UNION
		--level2
		SELECT 
			CL2.[SID], CL1.Code AS Level1Code, CL2.Code AS Level2Code, '' AS Level3Code, '' AS Level4Code, CL1.[Name] AS Level1Name, CL2.[Name] AS Level2Name, '' AS Level3Name, '' AS Level4Name
		FROM
		(
		SELECT
			CL.[SID], CL.Code, CL.[Name], CL.LevelNum, CL.ParentSID, CL.ParentLevelNum
		FROM 
			ProSolution.dbo.CollegeLevel CL WITH (NOLOCK)
			RIGHT JOIN ProSolution.dbo.AcademicYear AcYr WITH (NOLOCK) 
			ON ISNULL(CL.MaxAcademicYearID, '21/22') = AcYr.AcademicYearID
		WHERE
			CL.[Enabled] = 1 AND LevelNum = 2
		) CL2
			INNER JOIN
			(
			SELECT
				CL.SID, CL.Code, CL.[Name], CL.LevelNum, CL.ParentSID, CL.ParentLevelNum
			FROM 
				ProSolution.dbo.CollegeLevel CL WITH (NOLOCK)
				RIGHT JOIN ProSolution.dbo.AcademicYear AcYr WITH (NOLOCK) 
				ON ISNULL(CL.MaxAcademicYearID, '21/22') = AcYr.AcademicYearID
			WHERE
				CL.[Enabled] = 1 AND LevelNum = 1
			) CL1

			ON CL2.ParentSID  = CL1.[SID] AND CL2.ParentLevelNum = CL1.LevelNum

		UNION
		--Level3
		SELECT
			CL3.[SID], CL2.Level1Code, CL2.Level2Code, CL3.Code AS Level3Code, '' AS Level4Code, CL2.Level1Name AS Level1Name, CL2.Level2Name AS Level2Name, CL3.[Name] AS Level3Name, '' AS Level4Name
		FROM
		(
			SELECT
				CL2.[SID], CL1.Code AS Level1Code, CL2.Code AS Level2Code, CL2.LevelNum, CL1.[Name] AS Level1Name, CL2.[Name] AS Level2Name
			FROM
				(
				SELECT
					CL.[SID], CL.Code, CL.[Name], CL.LevelNum, CL.ParentSID, CL.ParentLevelNum
				FROM 
					ProSolution.dbo.CollegeLevel CL WITH (NOLOCK)
					RIGHT JOIN ProSolution.dbo.AcademicYear AcYr WITH (NOLOCK) 
					ON ISNULL(CL.MaxAcademicYearID, '21/22') = AcYr.AcademicYearID
				WHERE
					CL.[Enabled] = 1 AND LevelNum = 2
				) CL2
			
				INNER JOIN
				(
				SELECT
					CL.[SID], CL.Code, CL.[Name], CL.LevelNum, CL.ParentSID, CL.ParentLevelNum
				FROM 
					ProSolution.dbo.CollegeLevel CL WITH (NOLOCK)
					RIGHT JOIN ProSolution.dbo.AcademicYear AcYr WITH (NOLOCK) 
					ON ISNULL(CL.MaxAcademicYearID, '21/22') = AcYr.AcademicYearID
				WHERE
					CL.[Enabled] = 1 AND LevelNum = 1
				) CL1
			ON CL2.ParentSID  = CL1.[SID] AND CL2.ParentLevelNum = CL1.LevelNum
		) CL2

		INNER JOIN
		(
		SELECT
			CL.[SID], CL.Code, CL.[Name], CL.LevelNum, CL.ParentSID, CL.ParentLevelNum
		FROM 
			ProSolution.dbo.CollegeLevel CL WITH (NOLOCK)
			RIGHT JOIN ProSolution.dbo.AcademicYear AcYr WITH (NOLOCK) 
			ON ISNULL(CL.MaxAcademicYearID, '21/22') = AcYr.AcademicYearID
		WHERE
			CL.[Enabled] = 1 AND LevelNum = 3
		) CL3

		ON CL3.ParentSID = CL2.[SID] AND CL3.ParentLevelNum = CL2.LevelNum

		UNION
		--Level4
		SELECT
			CL4.[SID], CL3.Level1Code, CL3.Level2Code, CL3.Level3Code, CL4.Code AS Level4Code, CL3.Level1Name AS Level1Name, CL3.Level2Name AS Level2Name, CL3.[Name] AS Level3Name, CL4.[Name] AS Level4Name
		FROM
		(
			SELECT
				CL3.[SID], CL2.Level1Code, CL2.Level2Code, CL3.Code AS Level3Code, CL3.LevelNum, CL2.Level1Name, CL2.Level2Name, CL3.[Name]
			FROM
			(
				SELECT
					CL2.[SID], CL1.Code AS Level1Code, CL2.Code AS Level2Code, CL2.LevelNum, CL1.[Name] AS Level1Name, CL2.[Name] AS Level2Name
				FROM
				(
				SELECT
					CL.[SID], CL.Code, CL.[Name], CL.LevelNum, CL.ParentSID, CL.ParentLevelNum
				FROM 
					ProSolution.dbo.CollegeLevel CL WITH (NOLOCK)
					RIGHT JOIN ProSolution.dbo.AcademicYear AcYr WITH (NOLOCK) 
					ON ISNULL(CL.MaxAcademicYearID, '21/22') = AcYr.AcademicYearID
				WHERE
					CL.[Enabled] = 1 AND LevelNum = 2
				) CL2
				
				INNER JOIN
				(
				SELECT
					CL.[SID], CL.Code, CL.[Name], CL.LevelNum, CL.ParentSID, CL.ParentLevelNum
				FROM 
					ProSolution.dbo.CollegeLevel CL WITH (NOLOCK)
					RIGHT JOIN ProSolution.dbo.AcademicYear AcYr WITH (NOLOCK) 
					ON ISNULL(CL.MaxAcademicYearID, '21/22') = AcYr.AcademicYearID
				WHERE
					CL.[Enabled] = 1 AND LevelNum = 1
				) CL1
			
				ON CL2.ParentSID  = CL1.[SID] AND CL2.ParentLevelNum = CL1.LevelNum
		
			) CL2

			INNER JOIN
			(
			SELECT
				CL.[SID], CL.Code, CL.[Name], CL.LevelNum, CL.ParentSID, CL.ParentLevelNum
			FROM 
				ProSolution.dbo.CollegeLevel CL WITH (NOLOCK)
				RIGHT JOIN ProSolution.dbo.AcademicYear AcYr WITH (NOLOCK) 
				on ISNULL(CL.MaxAcademicYearID, '21/22') = AcYr.AcademicYearID
			WHERE
				CL.[Enabled] = 1 AND LevelNum = 3
			) CL3

			ON CL3.ParentSID = CL2.[SID] AND CL3.ParentLevelNum = CL2.LevelNum

		) CL3

		INNER JOIN
		(
		SELECT
			CL.[SID], CL.Code, CL.[Name], CL.LevelNum, CL.ParentSID, CL.ParentLevelNum
		FROM 
			ProSolution.dbo.CollegeLevel CL WITH (NOLOCK)
			RIGHT JOIN ProSolution.dbo.AcademicYear AcYr WITH (NOLOCK) 
			ON ISNULL(CL.MaxAcademicYearID, '21/22') = AcYr.AcademicYearID
		WHERE
			CL.[Enabled] = 1 AND LevelNum = 4
		) CL4

		ON CL4.ParentSID = CL3.[SID] AND CL4.ParentLevelNum = CL3.LevelNum

	) CollegeLevels
	
	ON [Off].[SID] = CollegeLevels.[SID]
	
GO

SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO





CREATE VIEW [vOG_2122_Student]
AS

------------------------------------------------
--Student Import Template for OneGrade VA
------------------------------------------------
SELECT
	T.AcademicYearID,
	T.LearnerRef, 
	LEFT(SDet.Surname,40) AS Surname, 
	LEFT(COALESCE (SDet.FirstForename, '') + ' ' + COALESCE (SDet.OtherForenames, ''),70) AS Forenames, 
	SDet.DateOfBirth AS DOB, 
	SDet.EthnicGroupID, 
	'' AS LearningDifficultyID, 
	SDet.Sex AS SexID, 
	CASE WHEN SDet.WideningParticipationID IS NULL THEN 0 ELSE 1 END AS FSM, 
	TG.Code AS TutorGroupCode,
	NULL AS UDFS1, NULL AS UDFS2, NULL AS UDFS3, NULL AS UDFS4, NULL AS UDFNum, NULL AS UDFDate,
	NULL AS UDFS5, NULL AS UDFS6, NULL AS UDFS7, NULL AS UDFS8, NULL AS UDFNum2

FROM 
	(
		--This will return the key enrolment records and avoid duplicates
		SELECT DISTINCT
			Min(SD.StudentDetailID) AS MinStudentDetailID,
			SD.AcademicYearID,								--*UniqueKey
			SD.RefNo AS LearnerRef							--*UniqueKey
	
		FROM         
			ProSolution.dbo.StudentDetail AS SD WITH (NOLOCK) 
			--Refer back to the vOG_2122_Enrolment View to only find students for Enrolments being Imported
			INNER JOIN vOG_2122_Enrolment WITH (NOLOCK)
				ON vOG_2122_Enrolment.AcademicYearID = SD.AcademicYearID
				AND vOG_2122_Enrolment.LearnerRef = SD.RefNo
		WHERE     
			SD.AcademicYearID = '21/22' 
		GROUP BY
			SD.AcademicYearID, SD.RefNo
	) T

--ensure that we join on T.MinStudentDetailID
INNER JOIN        
	ProSolution.dbo.StudentDetail AS SDet WITH (NOLOCK) 
	ON T.MinStudentDetailID = SDet.StudentDetailID
	LEFT JOIN ProSolution.dbo.Staff AS S WITH (NOLOCK) 
		ON S.StaffID = SDet.TutorID 	
		LEFT JOIN ProSolution.dbo.TutorGroup TG WITH (NOLOCK) 
			ON SDet.TutorGroupID = TG.TutorGroupID	




GO


SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO




CREATE VIEW [vOG_2122_QOE]
AS

------------------------------------------------
--QOE Import Template for OneGrade VA
------------------------------------------------

SELECT
SD.AcademicYearID,				--*UniqueKey
SD.RefNo,						--*UniqueKey
PLRLED.SourceQualificationCode,	--*UniqueKey
PLRLED.QualificationTitle,
PLRLED.grade,
PLRLED.AwardDate

FROM
ProSolution.dbo.PLRDownload PLRD with (nolock)
	INNER JOIN ProSolution.dbo.PLRLearnerEventDownload PLRLED with (nolock)
	ON PLRD.PLRDownloadID = PLRLED.PLRDownloadID
		INNER JOIN ProSolution.dbo.StudentDetail SD with (nolock)
		ON PLRD.StudentID = SD.StudentID
			INNER JOIN ProSolution.dbo.Learning_Aim LA with (nolock)
			ON LA.LEARNING_AIM_REF = PLRLED.SourceQualificationCode
				INNER JOIN
					(
					SELECT 
						MAX(PLRLEDM.PLRLearnerEventDownloadID) AS MaxPLRLearnerEventDownloadID
					FROM
						ProSolution.dbo.PLRLearnerEventDownload PLRLEDM with (nolock)
					GROUP BY
						PLRLEDM.PLRDownloadID, PLRLEDM.SourceQualificationCode
					) MaxPRLED
				ON PLRLED.PLRLearnerEventDownloadID = MaxPRLED.MaxPLRLearnerEventDownloadID
					--Refer back to the vOG_2122_Students to only return QOE for the Students being Imported.
					INNER JOIN vOG_2122_Student WITH (NOLOCK)
						ON vOG_2122_Student.AcademicYearID = SD.AcademicYearID
						AND vOG_2122_Student.LearnerRef = SD.RefNo

WHERE     
	SD.AcademicYearID = '21/22' 
	AND LA.NOTIONAL_NVQ_LEVEL_CODE = '2'								--Level 2 Qual
	AND ISNULL(PLRLED.Grade,'') <> ''									--Only where we have a grade
	AND (PLRLED.AwardDate IS NULL OR PLRLED.AwardDate < '2021/10/01')	--Only where Quals are awarded before Oct 1 2021 
																		--(Allows for Awards issued in August/Sept 2021 prior to start in AcYr 21/22 - due to delays in results allow Aug + Sept)



GO

SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO


CREATE VIEW [vOG_2122_StaffTeachingGroup]
AS

SELECT DISTINCT
O.AcademicYearID,
S.StaffRefNo AS StaffCode,
O.Code AS TeachingGroupCode

FROM
	ProSolution.dbo.RegisterLecturer RL WITH (NOLOCK)
		INNER JOIN ProSolution.dbo.RegisterCourse RC WITH (NOLOCK) 
		ON RL.RegisterID = RC.RegisterID
			INNER JOIN ProSolution.dbo.Offering O WITH (NOLOCK)	
			ON RC.OfferingID = O.OfferingID
				INNER JOIN ProSolution.dbo.Staff S WITH (NOLOCK) 
				ON RL.StaffID = S.StaffID
WHERE
	O.AcademicYearID = '21/22'
	AND S.IsCurrent=1
	AND EXISTS (SELECT DISTINCT TeachingGroupCode FROM vOG_2122_Enrolment WHERE TeachingGroupCode = O.Code)
GO


