USE [ProSolutionReports]
GO

/*
--Sample Import Views for OneGrade EM 20/21
--For use with ProSolution
--For OneGrade Version 1.23 onwards
*/

SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE VIEW [vOG_2021_EngMat_Enrolment]
AS

SELECT DISTINCT
	T.AcademicYearID,
	T.LearnerRef, 
	T.LearningAimRef,
	T.CourseCode, 
	T.CompletionStatusID,
	Enr.OutcomeID,
	Enr.Grade,
	T.StartDate,
	Enr.ExpectedEndDate,
	Enr.ActualEndDate,
	LTRIM(RTRIM(CollegeLevels.Level2Code)) + ' - ' + LEFT(CollegeLevels.Level2Name,200) AS UDFS1, --College Level Code and Name - alter to Level 1, 2, 3, 4 as desired
	NULL AS UDFS2, 
	NULL AS UDFS3, NULL AS UDFS4, 
	NULL AS UDFNum, NULL AS UDFDate,
	NULL AS UDFS5, NULL AS UDFS6, 
	NULL AS UDFS7, NULL AS UDFS8, 
	NULL AS UDFNum2, 
	[Off].code AS TeachingGroupCode,
	[off].[Name] AS TeachingGroupName

FROM
	(
			--This will return the key enrolment records and avoid duplicates
			SELECT DISTINCT
				Min(E.EnrolmentID) AS MinEnrolmentID,	
				SD.AcademicYearID,			--*UniqueKey
				SD.RefNo AS LearnerRef,		--*UniqueKey
				O.QualID AS LearningAimRef,	--*UniqueKey
				C.CourseCode,				--*UniqueKey
				E.CompletionStatusID,		--*UniqueKey
				E.StartDate					--*UniqueKey

			FROM         
				ProSolution.dbo.Enrolment AS E WITH (NOLOCK) 
				INNER JOIN ProSolution.dbo.Offering AS O WITH (NOLOCK)
					 ON E.OfferingID = O.OfferingID
						INNER JOIN ProSolution.dbo.Learning_Aim AS LA WITH (NOLOCK)
						ON O.QualID = LA.LEARNING_AIM_REF
							INNER JOIN ProSolution.dbo.StudentDetail AS SD WITH (NOLOCK)
							ON E.StudentDetailID = SD.StudentDetailID
								INNER JOIN vOG_CourseCode AS C WITH (NOLOCK)
								ON O.OfferingID = C.OfferingID

			WHERE     
				SD.AcademicYearID IN ('20/21')
				AND E.CompletionStatusID NOT IN ('X', '4', '5') --cancelled / transferred / Changes in Learning
				AND O.Name LIKE '%Math%' --Only include Maths quals
				AND O.OfferingStatusID NOT IN (2) --cancelled
				--AND ProSolution.dbo.GetAgeOn31Aug(SD.DateofBirth,'20/21') IN (16,17,18) --Don't restrict to just 16,17,18 year olds
				AND ISNUMERIC(LEFT(O.QualID,1)) = 1

			GROUP BY 
				SD.AcademicYearID, SD.RefNo, O.QualID, C.CourseCode, E.CompletionStatusID, E.StartDate
	) T
								
--ensure that we join on T.MinEnrolmentID
INNER JOIN ProSolution.dbo.Enrolment AS Enr WITH (NOLOCK)
ON T.MinEnrolmentID = Enr.EnrolmentID
	INNER JOIN ProSolution.dbo.Offering AS [Off] WITH (NOLOCK)
	ON Enr.OfferingID = [Off].OfferingID

	LEFT JOIN --College Structure
	(
		--Level1
		SELECT
			CL1.[SID], CL1.Code AS Level1Code, '' AS Level2Code, '' AS Level3Code, '' AS Level4Code, CL1.[Name] AS Level1Name, '' AS Level2Name, '' AS Level3Name, '' AS Level4Name
		FROM 
			ProSolution.dbo.CollegeLevel CL1 WITH (NOLOCK)
			RIGHT JOIN ProSolution.dbo.AcademicYear AcYr WITH (NOLOCK) 
			ON ISNULL(CL1.MaxAcademicYearID, '20/21') = AcYr.AcademicYearID
		WHERE
			CL1.[Enabled] = 1 AND LevelNum = 1
		
		UNION
		--level2
		SELECT 
			CL2.[SID], CL1.Code AS Level1Code, CL2.Code AS Level2Code, '' AS Level3Code, '' AS Level4Code, CL1.[Name] AS Level1Name, CL2.[Name] AS Level2Name, '' AS Level3Name, '' AS Level4Name
		FROM
		(
		SELECT
			CL.[SID], CL.Code, CL.[Name], CL.LevelNum, CL.ParentSID, CL.ParentLevelNum
		FROM 
			ProSolution.dbo.CollegeLevel CL WITH (NOLOCK)
			RIGHT JOIN ProSolution.dbo.AcademicYear AcYr WITH (NOLOCK) 
			ON ISNULL(CL.MaxAcademicYearID, '20/21') = AcYr.AcademicYearID
		WHERE
			CL.[Enabled] = 1 AND LevelNum = 2
		) CL2
			INNER JOIN
			(
			SELECT
				CL.SID, CL.Code, CL.[Name], CL.LevelNum, CL.ParentSID, CL.ParentLevelNum
			FROM 
				ProSolution.dbo.CollegeLevel CL WITH (NOLOCK)
				RIGHT JOIN ProSolution.dbo.AcademicYear AcYr WITH (NOLOCK) 
				ON ISNULL(CL.MaxAcademicYearID, '20/21') = AcYr.AcademicYearID
			WHERE
				CL.[Enabled] = 1 AND LevelNum = 1
			) CL1

			ON CL2.ParentSID  = CL1.[SID] AND CL2.ParentLevelNum = CL1.LevelNum

		UNION
		--Level3
		SELECT
			CL3.[SID], CL2.Level1Code, CL2.Level2Code, CL3.Code AS Level3Code, '' AS Level4Code, CL2.Level1Name AS Level1Name, CL2.Level2Name AS Level2Name, CL3.[Name] AS Level3Name, '' AS Level4Name
		FROM
		(
			SELECT
				CL2.[SID], CL1.Code AS Level1Code, CL2.Code AS Level2Code, CL2.LevelNum, CL1.[Name] AS Level1Name, CL2.[Name] AS Level2Name
			FROM
				(
				SELECT
					CL.[SID], CL.Code, CL.[Name], CL.LevelNum, CL.ParentSID, CL.ParentLevelNum
				FROM 
					ProSolution.dbo.CollegeLevel CL WITH (NOLOCK)
					RIGHT JOIN ProSolution.dbo.AcademicYear AcYr WITH (NOLOCK) 
					ON ISNULL(CL.MaxAcademicYearID, '20/21') = AcYr.AcademicYearID
				WHERE
					CL.[Enabled] = 1 AND LevelNum = 2
				) CL2
			
				INNER JOIN
				(
				SELECT
					CL.[SID], CL.Code, CL.[Name], CL.LevelNum, CL.ParentSID, CL.ParentLevelNum
				FROM 
					ProSolution.dbo.CollegeLevel CL WITH (NOLOCK)
					RIGHT JOIN ProSolution.dbo.AcademicYear AcYr WITH (NOLOCK) 
					ON ISNULL(CL.MaxAcademicYearID, '20/21') = AcYr.AcademicYearID
				WHERE
					CL.[Enabled] = 1 AND LevelNum = 1
				) CL1
			ON CL2.ParentSID  = CL1.[SID] AND CL2.ParentLevelNum = CL1.LevelNum
		) CL2

		INNER JOIN
		(
		SELECT
			CL.[SID], CL.Code, CL.[Name], CL.LevelNum, CL.ParentSID, CL.ParentLevelNum
		FROM 
			ProSolution.dbo.CollegeLevel CL WITH (NOLOCK)
			RIGHT JOIN ProSolution.dbo.AcademicYear AcYr WITH (NOLOCK) 
			ON ISNULL(CL.MaxAcademicYearID, '20/21') = AcYr.AcademicYearID
		WHERE
			CL.[Enabled] = 1 AND LevelNum = 3
		) CL3

		ON CL3.ParentSID = CL2.[SID] AND CL3.ParentLevelNum = CL2.LevelNum

		UNION
		--Level4
		SELECT
			CL4.[SID], CL3.Level1Code, CL3.Level2Code, CL3.Level3Code, CL4.Code AS Level4Code, CL3.Level1Name AS Level1Name, CL3.Level2Name AS Level2Name, CL3.[Name] AS Level3Name, CL4.[Name] AS Level4Name
		FROM
		(
			SELECT
				CL3.[SID], CL2.Level1Code, CL2.Level2Code, CL3.Code AS Level3Code, CL3.LevelNum, CL2.Level1Name, CL2.Level2Name, CL3.[Name]
			FROM
			(
				SELECT
					CL2.[SID], CL1.Code AS Level1Code, CL2.Code AS Level2Code, CL2.LevelNum, CL1.[Name] AS Level1Name, CL2.[Name] AS Level2Name
				FROM
				(
				SELECT
					CL.[SID], CL.Code, CL.[Name], CL.LevelNum, CL.ParentSID, CL.ParentLevelNum
				FROM 
					ProSolution.dbo.CollegeLevel CL WITH (NOLOCK)
					RIGHT JOIN ProSolution.dbo.AcademicYear AcYr WITH (NOLOCK) 
					ON ISNULL(CL.MaxAcademicYearID, '20/21') = AcYr.AcademicYearID
				WHERE
					CL.[Enabled] = 1 AND LevelNum = 2
				) CL2
				
				INNER JOIN
				(
				SELECT
					CL.[SID], CL.Code, CL.[Name], CL.LevelNum, CL.ParentSID, CL.ParentLevelNum
				FROM 
					ProSolution.dbo.CollegeLevel CL WITH (NOLOCK)
					RIGHT JOIN ProSolution.dbo.AcademicYear AcYr WITH (NOLOCK) 
					ON ISNULL(CL.MaxAcademicYearID, '20/21') = AcYr.AcademicYearID
				WHERE
					CL.[Enabled] = 1 AND LevelNum = 1
				) CL1
			
				ON CL2.ParentSID  = CL1.[SID] AND CL2.ParentLevelNum = CL1.LevelNum
		
			) CL2

			INNER JOIN
			(
			SELECT
				CL.[SID], CL.Code, CL.[Name], CL.LevelNum, CL.ParentSID, CL.ParentLevelNum
			FROM 
				ProSolution.dbo.CollegeLevel CL WITH (NOLOCK)
				RIGHT JOIN ProSolution.dbo.AcademicYear AcYr WITH (NOLOCK) 
				on ISNULL(CL.MaxAcademicYearID, '20/21') = AcYr.AcademicYearID
			WHERE
				CL.[Enabled] = 1 AND LevelNum = 3
			) CL3

			ON CL3.ParentSID = CL2.[SID] AND CL3.ParentLevelNum = CL2.LevelNum

		) CL3

		INNER JOIN
		(
		SELECT
			CL.[SID], CL.Code, CL.[Name], CL.LevelNum, CL.ParentSID, CL.ParentLevelNum
		FROM 
			ProSolution.dbo.CollegeLevel CL WITH (NOLOCK)
			RIGHT JOIN ProSolution.dbo.AcademicYear AcYr WITH (NOLOCK) 
			ON ISNULL(CL.MaxAcademicYearID, '20/21') = AcYr.AcademicYearID
		WHERE
			CL.[Enabled] = 1 AND LevelNum = 4
		) CL4

		ON CL4.ParentSID = CL3.[SID] AND CL4.ParentLevelNum = CL3.LevelNum

	) CollegeLevels
	
	ON [Off].[SID] = CollegeLevels.[SID]

UNION

SELECT DISTINCT
	T.AcademicYearID,
	T.LearnerRef, 
	T.LearningAimRef,
	T.CourseCode, 
	T.CompletionStatusID,
	Enr.OutcomeID,
	Enr.Grade,
	T.StartDate,
	Enr.ExpectedEndDate,
	Enr.ActualEndDate,
	LTRIM(RTRIM(CollegeLevels.Level2Code)) + ' - ' + LEFT(CollegeLevels.Level2Name,200) AS UDFS1, --College Level Code and Name - alter to Level 1, 2, 3, 4 as desired 
	NULL AS UDFS2, 
	NULL AS UDFS3, NULL AS UDFS4, 
	NULL AS UDFNum, NULL AS UDFDate,
	NULL AS UDFS5, NULL AS UDFS6, 
	NULL AS UDFS7, NULL AS UDFS8, 
	NULL AS UDFNum2, 
	[Off].code AS TeachingGroupCode,
	[Off].[Name] AS TeachingGroupName

FROM
	(
			--This will return the key enrolment records and avoid duplicates
			SELECT DISTINCT
				Min(E.EnrolmentID) AS MinEnrolmentID,	
				SD.AcademicYearID,			--*UniqueKey
				SD.RefNo AS LearnerRef,		--*UniqueKey
				O.QualID AS LearningAimRef,	--*UniqueKey
				C.CourseCode,				--*UniqueKey
				E.CompletionStatusID,		--*UniqueKey
				E.StartDate					--*UniqueKey

			FROM         
				ProSolution.dbo.Enrolment AS E WITH (NOLOCK) 
				INNER JOIN ProSolution.dbo.Offering AS O WITH (NOLOCK)
					 ON E.OfferingID = O.OfferingID
						INNER JOIN ProSolution.dbo.Learning_Aim AS LA WITH (NOLOCK)
						ON O.QualID = LA.LEARNING_AIM_REF
							INNER JOIN ProSolution.dbo.StudentDetail AS SD WITH (NOLOCK)
							ON E.StudentDetailID = SD.StudentDetailID
								INNER JOIN vOG_CourseCode AS C WITH (NOLOCK)
								ON O.OfferingID = C.OfferingID

			WHERE     
				SD.AcademicYearID IN ('20/21')
				AND E.CompletionStatusID NOT IN ('X', '4', '5') --cancelled / transferred / Changes in Learning
				AND O.Name LIKE '%English%' --Only include Maths quals
				AND O.OfferingStatusID NOT IN (2) --cancelled
				--AND ProSolution.dbo.GetAgeOn31Aug(SD.DateofBirth,'20/21') IN (16,17,18) --Don't restrict to just 16,17,18 year olds
				AND ISNUMERIC(LEFT(O.QualID,1)) = 1

			GROUP BY 
				SD.AcademicYearID, SD.RefNo, O.QualID, C.CourseCode, E.CompletionStatusID, E.StartDate
	) T
								
--ensure that we join on T.MinEnrolmentID
INNER JOIN ProSolution.dbo.Enrolment AS Enr WITH (NOLOCK)
ON T.MinEnrolmentID = Enr.EnrolmentID
	INNER JOIN ProSolution.dbo.Offering AS [Off] WITH (NOLOCK)
	ON Enr.OfferingID = [Off].OfferingID

		LEFT JOIN --College Structure
	(
		--Level1
		SELECT
			CL1.[SID], CL1.Code AS Level1Code, '' AS Level2Code, '' AS Level3Code, '' AS Level4Code, CL1.[Name] AS Level1Name, '' AS Level2Name, '' AS Level3Name, '' AS Level4Name
		FROM 
			ProSolution.dbo.CollegeLevel CL1 WITH (NOLOCK)
			RIGHT JOIN ProSolution.dbo.AcademicYear AcYr WITH (NOLOCK) 
			ON ISNULL(CL1.MaxAcademicYearID, '20/21') = AcYr.AcademicYearID
		WHERE
			CL1.[Enabled] = 1 AND LevelNum = 1
		
		UNION
		--level2
		SELECT 
			CL2.[SID], CL1.Code AS Level1Code, CL2.Code AS Level2Code, '' AS Level3Code, '' AS Level4Code, CL1.[Name] AS Level1Name, CL2.[Name] AS Level2Name, '' AS Level3Name, '' AS Level4Name
		FROM
		(
		SELECT
			CL.[SID], CL.Code, CL.[Name], CL.LevelNum, CL.ParentSID, CL.ParentLevelNum
		FROM 
			ProSolution.dbo.CollegeLevel CL WITH (NOLOCK)
			RIGHT JOIN ProSolution.dbo.AcademicYear AcYr WITH (NOLOCK) 
			ON ISNULL(CL.MaxAcademicYearID, '20/21') = AcYr.AcademicYearID
		WHERE
			CL.[Enabled] = 1 AND LevelNum = 2
		) CL2
			INNER JOIN
			(
			SELECT
				CL.SID, CL.Code, CL.[Name], CL.LevelNum, CL.ParentSID, CL.ParentLevelNum
			FROM 
				ProSolution.dbo.CollegeLevel CL WITH (NOLOCK)
				RIGHT JOIN ProSolution.dbo.AcademicYear AcYr WITH (NOLOCK) 
				ON ISNULL(CL.MaxAcademicYearID, '20/21') = AcYr.AcademicYearID
			WHERE
				CL.[Enabled] = 1 AND LevelNum = 1
			) CL1

			ON CL2.ParentSID  = CL1.[SID] AND CL2.ParentLevelNum = CL1.LevelNum

		UNION
		--Level3
		SELECT
			CL3.[SID], CL2.Level1Code, CL2.Level2Code, CL3.Code AS Level3Code, '' AS Level4Code, CL2.Level1Name AS Level1Name, CL2.Level2Name AS Level2Name, CL3.[Name] AS Level3Name, '' AS Level4Name
		FROM
		(
			SELECT
				CL2.[SID], CL1.Code AS Level1Code, CL2.Code AS Level2Code, CL2.LevelNum, CL1.[Name] AS Level1Name, CL2.[Name] AS Level2Name
			FROM
				(
				SELECT
					CL.[SID], CL.Code, CL.[Name], CL.LevelNum, CL.ParentSID, CL.ParentLevelNum
				FROM 
					ProSolution.dbo.CollegeLevel CL WITH (NOLOCK)
					RIGHT JOIN ProSolution.dbo.AcademicYear AcYr WITH (NOLOCK) 
					ON ISNULL(CL.MaxAcademicYearID, '20/21') = AcYr.AcademicYearID
				WHERE
					CL.[Enabled] = 1 AND LevelNum = 2
				) CL2
			
				INNER JOIN
				(
				SELECT
					CL.[SID], CL.Code, CL.[Name], CL.LevelNum, CL.ParentSID, CL.ParentLevelNum
				FROM 
					ProSolution.dbo.CollegeLevel CL WITH (NOLOCK)
					RIGHT JOIN ProSolution.dbo.AcademicYear AcYr WITH (NOLOCK) 
					ON ISNULL(CL.MaxAcademicYearID, '20/21') = AcYr.AcademicYearID
				WHERE
					CL.[Enabled] = 1 AND LevelNum = 1
				) CL1
			ON CL2.ParentSID  = CL1.[SID] AND CL2.ParentLevelNum = CL1.LevelNum
		) CL2

		INNER JOIN
		(
		SELECT
			CL.[SID], CL.Code, CL.[Name], CL.LevelNum, CL.ParentSID, CL.ParentLevelNum
		FROM 
			ProSolution.dbo.CollegeLevel CL WITH (NOLOCK)
			RIGHT JOIN ProSolution.dbo.AcademicYear AcYr WITH (NOLOCK) 
			ON ISNULL(CL.MaxAcademicYearID, '20/21') = AcYr.AcademicYearID
		WHERE
			CL.[Enabled] = 1 AND LevelNum = 3
		) CL3

		ON CL3.ParentSID = CL2.[SID] AND CL3.ParentLevelNum = CL2.LevelNum

		UNION
		--Level4
		SELECT
			CL4.[SID], CL3.Level1Code, CL3.Level2Code, CL3.Level3Code, CL4.Code AS Level4Code, CL3.Level1Name AS Level1Name, CL3.Level2Name AS Level2Name, CL3.[Name] AS Level3Name, CL4.[Name] AS Level4Name
		FROM
		(
			SELECT
				CL3.[SID], CL2.Level1Code, CL2.Level2Code, CL3.Code AS Level3Code, CL3.LevelNum, CL2.Level1Name, CL2.Level2Name, CL3.[Name]
			FROM
			(
				SELECT
					CL2.[SID], CL1.Code AS Level1Code, CL2.Code AS Level2Code, CL2.LevelNum, CL1.[Name] AS Level1Name, CL2.[Name] AS Level2Name
				FROM
				(
				SELECT
					CL.[SID], CL.Code, CL.[Name], CL.LevelNum, CL.ParentSID, CL.ParentLevelNum
				FROM 
					ProSolution.dbo.CollegeLevel CL WITH (NOLOCK)
					RIGHT JOIN ProSolution.dbo.AcademicYear AcYr WITH (NOLOCK) 
					ON ISNULL(CL.MaxAcademicYearID, '20/21') = AcYr.AcademicYearID
				WHERE
					CL.[Enabled] = 1 AND LevelNum = 2
				) CL2
				
				INNER JOIN
				(
				SELECT
					CL.[SID], CL.Code, CL.[Name], CL.LevelNum, CL.ParentSID, CL.ParentLevelNum
				FROM 
					ProSolution.dbo.CollegeLevel CL WITH (NOLOCK)
					RIGHT JOIN ProSolution.dbo.AcademicYear AcYr WITH (NOLOCK) 
					ON ISNULL(CL.MaxAcademicYearID, '20/21') = AcYr.AcademicYearID
				WHERE
					CL.[Enabled] = 1 AND LevelNum = 1
				) CL1
			
				ON CL2.ParentSID  = CL1.[SID] AND CL2.ParentLevelNum = CL1.LevelNum
		
			) CL2

			INNER JOIN
			(
			SELECT
				CL.[SID], CL.Code, CL.[Name], CL.LevelNum, CL.ParentSID, CL.ParentLevelNum
			FROM 
				ProSolution.dbo.CollegeLevel CL WITH (NOLOCK)
				RIGHT JOIN ProSolution.dbo.AcademicYear AcYr WITH (NOLOCK) 
				on ISNULL(CL.MaxAcademicYearID, '20/21') = AcYr.AcademicYearID
			WHERE
				CL.[Enabled] = 1 AND LevelNum = 3
			) CL3

			ON CL3.ParentSID = CL2.[SID] AND CL3.ParentLevelNum = CL2.LevelNum

		) CL3

		INNER JOIN
		(
		SELECT
			CL.[SID], CL.Code, CL.[Name], CL.LevelNum, CL.ParentSID, CL.ParentLevelNum
		FROM 
			ProSolution.dbo.CollegeLevel CL WITH (NOLOCK)
			RIGHT JOIN ProSolution.dbo.AcademicYear AcYr WITH (NOLOCK) 
			ON ISNULL(CL.MaxAcademicYearID, '20/21') = AcYr.AcademicYearID
		WHERE
			CL.[Enabled] = 1 AND LevelNum = 4
		) CL4

		ON CL4.ParentSID = CL3.[SID] AND CL4.ParentLevelNum = CL3.LevelNum

	) CollegeLevels
	
	ON [Off].[SID] = CollegeLevels.[SID]

GO


SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO





CREATE VIEW [vOG_2021_EngMat_QOE]
AS

--We need ALL English and Maths QOEs
--This is so you can identify students in OneGrade who may not be enrolled
--on English or Maths who may need to be.

SELECT
	SD.AcademicYearID,				--*UniqueKey
	SD.RefNo,						--*UniqueKey
	PLRLED.SourceQualificationCode,	--*UniqueKey
	PLRLED.QualificationTitle,
	PLRLED.grade,					--*UniqueKey
	PLRLED.AwardDate				--*UniqueKey

FROM
	ProSolution.dbo.PLRDownload PLRD with (nolock)
		INNER JOIN ProSolution.dbo.PLRLearnerEventDownload PLRLED with (nolock)
		ON PLRD.PLRDownloadID = PLRLED.PLRDownloadID
			INNER JOIN ProSolution.dbo.StudentDetail SD with (nolock)
			ON PLRD.StudentID = SD.StudentID

WHERE     
	SD.AcademicYearID = '20/21' 
	AND ISNULL(PLRLED.Grade,'') <> '' --Only where we have a grade
	AND PLRLED.AwardDate IS NOT NULL
	AND PLRLED.QualificationTitle LIKE '%Math%'
	AND PLRLED.AwardDate < '2020/09/01' --Only where Quals are awarded before Sept 1 2020 (Allows for Awards issued in August 2020 prior to start in AcYr 20/21)
	--AND ProSolution.dbo.GetAgeOn31Aug(SD.DateofBirth,'20/21') IN (16,17,18)


UNION 

SELECT
	SD.AcademicYearID,					--*UniqueKey
	SD.RefNo,							--*UniqueKey
	PLRLED.SourceQualificationCode,		--*UniqueKey
	PLRLED.QualificationTitle,
	PLRLED.grade,						--*UniqueKey
	PLRLED.AwardDate					--*UniqueKey

FROM
	ProSolution.dbo.PLRDownload PLRD with (nolock)
		INNER JOIN ProSolution.dbo.PLRLearnerEventDownload PLRLED with (nolock)
		ON PLRD.PLRDownloadID = PLRLED.PLRDownloadID
			INNER JOIN ProSolution.dbo.StudentDetail SD with (nolock)
			ON PLRD.StudentID = SD.StudentID

WHERE     
	SD.AcademicYearID = '20/21' 
	AND ISNULL(PLRLED.Grade,'') <> '' --Only where we have a grade
	AND PLRLED.AwardDate IS NOT NULL
	AND PLRLED.QualificationTitle LIKE '%English%'
	AND PLRLED.AwardDate < '2020/09/01' --Only where Quals are awarded before Sept 1 2020 (Allows for Awards issued in August 2020 prior to start in AcYr 20/21)
	--AND ProSolution.dbo.GetAgeOn31Aug(SD.DateofBirth,'20/21') IN (16,17,18)

UNION
--now union with the Generic GCSE Maths Grade

SELECT 
	ProSolution.dbo.StudentDetail.AcademicYearID
	,ProSolution.dbo.StudentDetail.RefNo
	,'MATHGCSE' AS SourceQualificationCode --MATHGCSE is a Known Maths GCSE qualification recognised by OneGrade
	,'Highest Maths GCSE recorded by College MIS' AS QualificationTitle
	,ProSolution.dbo.StudentDetail.GCSEMathsQualificationGrade
	,'2020-08-01 00:00:00' AS AchievedDate --Assume that this was awarded in Aug 2020

FROM
	ProSolution.dbo.StudentDetail with (nolock)

WHERE 
	ProSolution.dbo.StudentDetail.AcademicYearID = '20/21'
	AND LEN(ISNULL(ProSolution.dbo.StudentDetail.GCSEMathsQualificationGrade,'')) > 0

UNION
--and union with the Generic GCSE English Grade

SELECT 
	ProSolution.dbo.StudentDetail.AcademicYearID
	,ProSolution.dbo.StudentDetail.RefNo
	,'ENGGCSE' AS SourceQualificationCode --ENGGCSE is a Known English GCSE qualification recognised by OneGrade
	,'Highest English GCSE recorded by College MIS' AS QualificationTitle
	,ProSolution.dbo.StudentDetail.GCSEEnglishQualificationGrade
	,'2020-08-01 00:00:00' AS AchievedDate --Assume that this was awarded in Aug 2020

FROM
	ProSolution.dbo.StudentDetail with (nolock)

WHERE 
	ProSolution.dbo.StudentDetail.AcademicYearID = '20/21'
	AND LEN(ISNULL(ProSolution.dbo.StudentDetail.GCSEEnglishQualificationGrade,'')) > 0

GO

SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO



CREATE View [vOG_2021_EngMat_Student]
AS

--Get all of the Students with Enrolments
SELECT DISTINCT
	T.AcademicYearID,
	T.LearnerRef, 
	LEFT(SDet.Surname,40) AS Surname, 
	LEFT(COALESCE (SDet.FirstForename, '') + ' ' + COALESCE (SDet.OtherForenames, ''),70) AS Forenames, 
	SDet.DateOfBirth AS DOB, 
	SDet.EthnicGroupID, 
	'' AS LearningDifficultyID, 
	SDet.Sex AS SexID, 
	CASE WHEN SDet.WideningParticipationID IS NULL THEN 0 ELSE 1 END AS FSM, 
	TG.Code AS TutorGroupCode,
	NULL AS UDFS1, NULL AS UDFS2, 
	NULL AS UDFS3, NULL AS UDFS4, 
	NULL AS UDFNum, NULL AS UDFDate,
	NULL AS UDFS5, NULL AS UDFS6, 
	SDet.GCSEEnglishQualificationGrade AS UDFS7, SDet.GCSEMathsQualificationGrade AS UDFS8, 
	NULL AS UDFNum2,
	CASE WHEN SDet.LearningDiffOrDisID = 1 THEN 'Y' ELSE 'N' END AS LearningDifforDis,
	SDet.Overseas,
	CASE WHEN ISNULL(SDet.PlannedLearningHours,0) >=150 THEN 'N' ELSE 'Y' END AS Under150Hrs
	

FROM 
	(
		--This will return the key enrolment records and avoid duplicates
		SELECT DISTINCT
			Min(SD.StudentDetailID) AS MinStudentDetailID,
			SD.AcademicYearID,								--*UniqueKey
			SD.RefNo AS LearnerRef							--*UniqueKey
	
		FROM         
			ProSolution.dbo.StudentDetail AS SD WITH (NOLOCK) 
			--Refer back to the vOG_2021_Enrolment View to only find students for Enrolments being Imported
			INNER JOIN vOG_2021_EngMat_Enrolment WITH (NOLOCK)
				ON vOG_2021_EngMat_Enrolment.AcademicYearID = SD.AcademicYearID
				AND vOG_2021_EngMat_Enrolment.LearnerRef = SD.RefNo
		WHERE     
			SD.AcademicYearID = '20/21' 
		GROUP BY
			SD.AcademicYearID, SD.RefNo
	) T

--ensure that we join on T.MinStudentDetailID
INNER JOIN        
	ProSolution.dbo.StudentDetail AS SDet WITH (NOLOCK) 
	ON T.MinStudentDetailID = SDet.StudentDetailID
	LEFT JOIN ProSolution.dbo.Staff AS S WITH (NOLOCK) 
		ON S.StaffID = SDet.TutorID 	
		LEFT JOIN ProSolution.dbo.TutorGroup TG WITH (NOLOCK) 
			ON SDet.TutorGroupID = TG.TutorGroupID	
         

--And Union together with Students aged 16-18 who have QOE in Maths and English
UNION 

SELECT DISTINCT
	SD.AcademicYearID,
	SD.RefNo AS LearnerRef, 
	LEFT(SD.Surname,40) AS Surname, 
	LEFT(COALESCE (SD.FirstForename, '') + ' ' + COALESCE (SD.OtherForenames, ''),70) AS Forenames, 
	SD.DateOfBirth AS DOB, 
	SD.EthnicGroupID, 
	'' AS LearningDifficultyID, 
	SD.Sex AS SexID, 
	CASE WHEN SD.WideningParticipationID IS NULL THEN 0 ELSE 1 END AS FSM, 
	T.Code AS TutorGroupCode,
	NULL AS UDFS1, NULL AS UDFS2, NULL AS UDFS3, NULL AS UDFS4, NULL AS UDFNum, NULL AS UDFDate,
	NULL AS UDFS5, NULL AS UDFS6, GCSEEnglishQualificationGrade AS UDFS7, GCSEMathsQualificationGrade AS UDFS8, NULL AS UDFNum2,
	CASE WHEN SD.LearningDiffOrDisID = 1 THEN 'Y' ELSE 'N' END AS LearningDiforDis,
	SD.Overseas,
	CASE WHEN ISNULL(SD.PlannedLearningHours,0) >=150 THEN 'N' ELSE 'Y' END AS Under150Hrs
	
FROM         
	ProSolution.dbo.StudentDetail AS SD WITH (NOLOCK) 
		LEFT JOIN ProSolution.dbo.Staff AS S WITH (NOLOCK) ON 
		S.StaffID = SD.TutorID 
			LEFT JOIN ProSolution.dbo.TutorGroup T WITH (NOLOCK) ON
			SD.TutorGroupID = T.TutorGroupID	
		
WHERE     
	SD.AcademicYearID = '20/21' 
	AND ProSolution.dbo.GetAgeOn31Aug(SD.DateofBirth,'20/21') IN (16,17,18)
	AND SD.StudentDetailID IN (--Include Students with QOE in Maths/English
								SELECT DISTINCT
									StudentDetailID 
								FROM 
									vOG_2021_EngMat_QOE
								WHERE
									vOG_2021_EngMat_QOE.AcademicYearID = SD.AcademicYearID	
									AND vOG_2021_EngMat_QOE.RefNo = SD.RefNo
								)


GO

SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO



CREATE VIEW [vOG_2021_EngMat_StaffTeachingGroup]
AS

----------------------------------------------
--StaffTeachingGroup Template for OneGrade EM
----------------------------------------------
SELECT DISTINCT
O.AcademicYearID,
S.StaffRefNo AS StaffCode,
O.Code AS TeachingGroupCode

FROM
	ProSolution.dbo.RegisterLecturer RL WITH (NOLOCK)
		INNER JOIN ProSolution.dbo.RegisterCourse RC WITH (NOLOCK) 
		ON RL.RegisterID = RC.RegisterID
			INNER JOIN ProSolution.dbo.Offering O WITH (NOLOCK)	
			ON RC.OfferingID = O.OfferingID
				INNER JOIN ProSolution.dbo.Staff S WITH (NOLOCK) 
				ON RL.StaffID = S.StaffID
WHERE
	O.AcademicYearID = '20/21'
	AND S.IsCurrent=1
	AND EXISTS (SELECT DISTINCT TeachingGroupCode FROM vOG_2021_EngMat_Enrolment WHERE TeachingGroupCode = O.Code)

GO


